performance/laplace
===================

This times the Laplacian inversions called in the test-laplace integrated tests
to benchmark performance. It does not check correctness.

This test uses both the old-style free function `invert_laplace`, as well as the
new class interface `Laplacian`.

For details on the flags used, see the Laplacian inversion documentation.
